Changelog
==========

This document records all notable changes to `HTTPie <https://httpie.org>`_.
This project adheres to `Semantic Versioning <https://semver.org/>`_.

0.1.1 (2020-04-07)
------------------

***Added***

***Fixed***
* pep8 compatibility
* bug when specifying compartment-specific initial populations not as probabilities

***Dependencies***

***Deprecated***

0.1.0 (2020-04-07)
------------------

***Added***
* Created the project using COOKIETEMPLE

***Fixed***

***Dependencies***

***Deprecated***
